@@ -1178,7 +1178,165 @@ extern const unsigned char qmlData alignas(16) [] = {
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_MSVC(4573)
 extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
-extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = { { 0, 0, nullptr, nullptr } };
+extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
+{ 19, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
+    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
+    const auto *aotContext = &c;
+    Q_UNUSED(aotContext);
+    argTypes[0] = QMetaType::fromType<double>();
+}, 
+    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
+Q_UNUSED(aotContext)
+Q_UNUSED(argv)
+// expression for width at line 86, column 13
+struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
+Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
+void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
+    aotContext->mark(v2_0, markStack);
+}
+const QQmlPrivate::AOTCompiledContext *aotContext;
+void **argv;
+QObject *v2_0 = nullptr;
+double v2_2;
+double v2_6;
+double v2_8;
+};
+Storage s(aotContext, argv);
+aotContext->setLocals(&s);
+// generate_LoadQmlContextPropertyLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+while (!aotContext->loadScopeObjectPropertyLookup(55, &s.v2_0)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+aotContext->initLoadScopeObjectPropertyLookup(55);
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = double();
+}
+return;
+}
+}
+{
+}
+// generate_GetLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+while (!aotContext->getObjectLookup(56, s.v2_0, &s.v2_2)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+aotContext->initGetObjectLookup(56, s.v2_0);
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = double();
+}
+return;
+}
+}
+{
+}
+// generate_StoreReg
+{
+}
+// generate_LoadInt
+s.v2_6 = double(2);
+{
+}
+// generate_Sub
+s.v2_8 = (s.v2_2 - s.v2_6);
+{
+}
+{
+}
+// generate_Ret
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = s.v2_8;
+}
+return;
+}
+ },{ 20, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
+    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
+    const auto *aotContext = &c;
+    Q_UNUSED(aotContext);
+    argTypes[0] = QMetaType::fromType<double>();
+}, 
+    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
+Q_UNUSED(aotContext)
+Q_UNUSED(argv)
+// expression for height at line 87, column 13
+struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
+Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
+void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
+    aotContext->mark(v2_0, markStack);
+}
+const QQmlPrivate::AOTCompiledContext *aotContext;
+void **argv;
+QObject *v2_0 = nullptr;
+double v2_2;
+double v2_4;
+};
+Storage s(aotContext, argv);
+aotContext->setLocals(&s);
+// generate_LoadQmlContextPropertyLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+while (!aotContext->loadScopeObjectPropertyLookup(57, &s.v2_0)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(2);
+#endif
+aotContext->initLoadScopeObjectPropertyLookup(57);
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = double();
+}
+return;
+}
+}
+{
+}
+// generate_GetLookup
+#ifndef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+while (!aotContext->getObjectLookup(58, s.v2_0, &s.v2_2)) {
+#ifdef QT_NO_DEBUG
+aotContext->setInstructionPointer(4);
+#endif
+aotContext->initGetObjectLookup(58, s.v2_0);
+if (aotContext->engine->hasError()) {
+aotContext->setReturnValueUndefined();
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = double();
+}
+return;
+}
+}
+{
+}
+// generate_Decrement
+{
+auto converted = s.v2_2;
+s.v2_4 = (--converted);
+}
+{
+}
+{
+}
+// generate_Ret
+if (argv[0]) {
+    *static_cast<double *>(argv[0]) = s.v2_4;
+}
+return;
+}
+ },{ 0, 0, nullptr, nullptr }};
 QT_WARNING_POP
 }
 }
